@@ -102,12 +102,12 @@ class account():
         #start up location tracking
         loop = gobject.MainLoop()
         self.control = location.GPSDControl.get_default()
-        device = location.GPSDevice()
+        self.device = location.GPSDevice()
         self.control.set_properties(preferred_method=location.METHOD_ACWP,
                        preferred_interval=location.INTERVAL_DEFAULT)
  
         self.control.connect("error-verbose", self.on_error, loop)
-        device.connect("changed", self.on_changed, self.control)
+        self.device.connect("changed", self.on_changed, self.control)
         self.control.connect("gpsd-stopped", self.on_stop, loop)
  
         gobject.idle_add(self.start_location, self.control)
@@ -904,6 +904,12 @@ class account():
         #see if we have just an empty string (eg eroneous button press)
         if (tweet == ""):
             return False
+        if (self.controller.location):
+            if self.device.fix:
+                if self.device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                    print "lat = %f, long = %f" % self.device.fix[4:6]
+                    self.lat, self.long = self.device.fix[4:6]
+            
         #if (self.controller.location):
         #    self.updateLocation()
         try:
