@@ -1147,51 +1147,55 @@ class Witter():
             #self.ui.window.setActiveWindow()
             
     def _on_orientation_signal(self, orientation, stand, face, x, y, z):
-         if ((orientation == 'portrait') & (self.ui.orientation != 'Landscape') ):
-            print "switching to portrait"
-            #self.ui.orientation=orientation
-            #self.ui.cell.set_property('wrap-width', 400)
-            
-            self.ui.icon_size = 30
-            self.ui.load_theme_icons()
-            self.ui.width=400
-            if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
+         
+         if (self.ui.activeWindow.get_is_topmost()):
+             if ((orientation == 'portrait') & (self.ui.orientation != 'Landscape') ):
+                print "switching to portrait"
+                #self.ui.orientation=orientation
+                #self.ui.cell.set_property('wrap-width', 400)
                 
-                self.ui.toggleviewto(self.ui.activeWin)
-            self.ui.current_orientation = 'portrait'
-            
-         if ((orientation == 'landscape') & (self.ui.orientation != 'Portrait')):
-            print "switching to landscape"
-            #self.ui.orientation=orientation
-            #self.ui.cell.set_property('wrap-width', 730)
-            
-            self.ui.icon_size = 48
-            self.ui.load_theme_icons()
-            self.ui.define_ui_buttons()
-            self.ui.width=720
-            if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
-                self.ui.toggleviewto(self.ui.activeWin)
-            
-            self.ui.hide_portrait_keyboard()
-            self.ui.current_orientation = 'landscape'
-         #print "refresh current view"
-         #curView = self.ui.getCurrentView()  
-         #if (curView == self.ui.TIMELINE_VIEW):
-         #   self.ui.switch_view_to("timeline")
-         #elif (curView == self.ui.DM_VIEW):
-         #   self.ui.switch_view_to("direct")
-         #elif (curView == self.ui.MENTIONS_VIEW):
-         #   self.ui.switch_view_to("mentions")
-         #elif (curView == self.ui.PUBLIC_VIEW):
-         #   self.ui.switch_view_to("public")
-         #elif (curView == self.ui.TRENDS_VIEW):
-         #   self.ui.switch_view_to("trends")
-         #elif (curView == self.ui.FRIENDS_VIEW):
-         #   self.ui.switch_view_to("friends")
-         #elif (curView == self.ui.SEARCH_VIEW):
-         #   self.ui.switch_view_to("search")
-         #elif (curView == self.ui.USERHIST_VIEW):
-         #   self.ui.switch_view_to("user")
+                self.ui.icon_size = 30
+                self.ui.load_theme_icons()
+                self.ui.width=400
+                if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
+                    
+                    self.ui.toggleviewto(self.ui.activeWin)
+                self.ui.current_orientation = 'portrait'
+                
+             if ((orientation == 'landscape') & (self.ui.orientation != 'Portrait')):
+                print "switching to landscape"
+                #self.ui.orientation=orientation
+                #self.ui.cell.set_property('wrap-width', 730)
+                
+                self.ui.icon_size = 48
+                self.ui.load_theme_icons()
+                self.ui.define_ui_buttons()
+                self.ui.width=720
+                if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
+                    self.ui.toggleviewto(self.ui.activeWin)
+                
+                self.ui.hide_portrait_keyboard()
+                self.ui.current_orientation = 'landscape'
+         else:
+            print "not top most window, not rotating"
+             #print "refresh current view"
+             #curView = self.ui.getCurrentView()  
+             #if (curView == self.ui.TIMELINE_VIEW):
+             #   self.ui.switch_view_to("timeline")
+             #elif (curView == self.ui.DM_VIEW):
+             #   self.ui.switch_view_to("direct")
+             #elif (curView == self.ui.MENTIONS_VIEW):
+             #   self.ui.switch_view_to("mentions")
+             #elif (curView == self.ui.PUBLIC_VIEW):
+             #   self.ui.switch_view_to("public")
+             #elif (curView == self.ui.TRENDS_VIEW):
+             #   self.ui.switch_view_to("trends")
+             #elif (curView == self.ui.FRIENDS_VIEW):
+             #   self.ui.switch_view_to("friends")
+             #elif (curView == self.ui.SEARCH_VIEW):
+             #   self.ui.switch_view_to("search")
+             #elif (curView == self.ui.USERHIST_VIEW):
+             #   self.ui.switch_view_to("user")
             
     def establish_connection(self):
         magic = 0xAA55 
